summaryrefslogtreecommitdiffstats
path: root/kolourpaint/kpview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kolourpaint/kpview.h')
-rw-r--r--kolourpaint/kpview.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kolourpaint/kpview.h b/kolourpaint/kpview.h
index 613cafd2..4460a8ac 100644
--- a/kolourpaint/kpview.h
+++ b/kolourpaint/kpview.h
@@ -81,7 +81,7 @@ public:
kpViewManager *viewManager,
kpView *buddyView,
kpViewScrollableContainer *scrollableContainer,
- TQWidget *tqparent, const char *name);
+ TQWidget *parent, const char *name);
/**
* Destructs this view. Informs the viewManager() that the mouse
@@ -344,7 +344,7 @@ protected:
public:
/**
* Adds a region (in view coordinates) to the dirty area that is
* repainted when the tqparent @ref kpViewManager is set not to queue
* updates.
*
* @param region Region (in view coordinates) that needs repainting.
@@ -355,7 +355,7 @@ public:
* Convenience function. Same as above.
*
* Adds a rectangle (in view coordinates) to the dirty area that is
* repainted when the tqparent @ref kpViewManager is set not to queue
* updates.
*
* @param rect Rectangle (in view coordinates) that needs repainting.
@@ -344,7 +344,7 @@ protected:
/**
* Adds a region (in view coordinates) to the dirty area that is
- * repainted when the tqparent @ref kpViewManager is set not to queue
+ * repainted when the parent @ref kpViewManager is set not to queue
* updates.
*
@@ -355,7 +355,7 @@ public:
*
* Adds a rectangle (in view coordinates) to the dirty area that is
- * repainted when the tqparent @ref kpViewManager is set not to queue
+ * repainted when the parent @ref kpViewManager is set not to queue
* updates.
*